<?php

require_once dirname(__FILE__) . '/../../../prods/src/ProdsQuery.class.php';

/**
 * Test class for ProdsQuery.
 * Generated by PHPUnit on 2011-02-24 at 16:39:15.
 */
class ProdsQueryTest extends PHPUnit_Framework_TestCase {

    /**
     * @var ProdsQuery
     */
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp() {
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown() {

    }

    /**
     * @todo Implement testGetMetadataNamesForAllFiles().
     */
    public function testGetMetadataNamesForAllFiles() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

    /**
     * @todo Implement testGetMetadataNamesForAllDirs().
     */
    public function testGetMetadataNamesForAllDirs() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

    /**
     * @todo Implement testGetResources().
     */
    public function testGetResources() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

}

?>
