<?php

/* This file is generated by setRodsAPINum.php   Please modify that file if you wish to update the    API number.            */

$GLOBALS['PRODS_API_NUMS'] = array(
    'FILE_CREATE_AN' => '500',
    'FILE_OPEN_AN' => '501',
    'FILE_WRITE_AN' => '502',
    'FILE_CLOSE_AN' => '503',
    'FILE_LSEEK_AN' => '504',
    'FILE_READ_AN' => '505',
    'FILE_UNLINK_AN' => '506',
    'FILE_MKDIR_AN' => '507',
    'FILE_CHMOD_AN' => '508',
    'FILE_RMDIR_AN' => '509',
    'FILE_STAT_AN' => '510',
    'FILE_FSTAT_AN' => '511',
    'FILE_FSYNC_AN' => '512',
    'FILE_STAGE_AN' => '513',
    'FILE_GET_FS_FREE_SPACE_AN' => '514',
    'FILE_OPENDIR_AN' => '515',
    'FILE_CLOSEDIR_AN' => '516',
    'FILE_READDIR_AN' => '517',
    'FILE_PUT_AN' => '518',
    'FILE_GET_AN' => '519',
    'FILE_CHKSUM_AN' => '520',
    'CHK_N_V_PATH_PERM_AN' => '521',
    'FILE_RENAME_AN' => '522',
    'FILE_TRUNCATE_AN' => '523',
    'DATA_OBJ_CREATE_AN' => '601',
    'DATA_OBJ_OPEN_AN' => '602',
    'DATA_OBJ_READ_AN' => '603',
    'DATA_OBJ_WRITE_AN' => '604',
    'DATA_OBJ_CLOSE_AN' => '605',
    'DATA_OBJ_PUT_AN' => '606',
    'DATA_PUT_AN' => '607',
    'DATA_OBJ_GET_AN' => '608',
    'DATA_GET_AN' => '609',
    'DATA_OBJ_REPL_AN' => '610',
    'DATA_COPY_AN' => '611',
    'DATA_OBJ_LSEEK_AN' => '612',
    'DATA_OBJ_COPY_AN' => '613',
    'SIMPLE_QUERY_AN' => '614',
    'DATA_OBJ_UNLINK_AN' => '615',
    'COLL_CREATE_AN' => '616',
    'RM_COLL_OLD_AN' => '617',
    'REG_COLL_AN' => '618',
    'REG_DATA_OBJ_AN' => '619',
    'UNREG_DATA_OBJ_AN' => '620',
    'REG_REPLICA_AN' => '621',
    'MOD_DATA_OBJ_META_AN' => '622',
    'RULE_EXEC_SUBMIT_AN' => '623',
    'RULE_EXEC_DEL_AN' => '624',
    'EXEC_MY_RULE_AN' => '625',
    'OPR_COMPLETE_AN' => '626',
    'DATA_OBJ_RENAME_AN' => '627',
    'DATA_OBJ_RSYNC_AN' => '628',
    'DATA_OBJ_CHKSUM_AN' => '629',
    'PHY_PATH_REG_AN' => '630',
    'DATA_OBJ_PHYMV_AN' => '631',
    'DATA_OBJ_TRIM_AN' => '632',
    'OBJ_STAT_AN' => '633',
    'EXEC_CMD_AN' => '634',
    'SUB_STRUCT_FILE_CREATE_AN' => '635',
    'SUB_STRUCT_FILE_OPEN_AN' => '636',
    'SUB_STRUCT_FILE_READ_AN' => '637',
    'SUB_STRUCT_FILE_WRITE_AN' => '638',
    'SUB_STRUCT_FILE_CLOSE_AN' => '639',
    'SUB_STRUCT_FILE_UNLINK_AN' => '640',
    'SUB_STRUCT_FILE_STAT_AN' => '641',
    'SUB_STRUCT_FILE_FSTAT_AN' => '642',
    'SUB_STRUCT_FILE_LSEEK_AN' => '643',
    'SUB_STRUCT_FILE_RENAME_AN' => '644',
    'QUERY_SPEC_COLL_AN' => '645',
    'MOD_COLL_AN' => '646',
    'SUB_STRUCT_FILE_MKDIR_AN' => '647',
    'SUB_STRUCT_FILE_RMDIR_AN' => '648',
    'SUB_STRUCT_FILE_OPENDIR_AN' => '649',
    'SUB_STRUCT_FILE_READDIR_AN' => '650',
    'SUB_STRUCT_FILE_CLOSEDIR_AN' => '651',
    'DATA_OBJ_TRUNCATE_AN' => '652',
    'SUB_STRUCT_FILE_TRUNCATE_AN' => '653',
    'GET_XMSG_TICKET_AN' => '654',
    'SEND_XMSG_AN' => '655',
    'RCV_XMSG_AN' => '656',
    'SUB_STRUCT_FILE_GET_AN' => '657',
    'SUB_STRUCT_FILE_PUT_AN' => '658',
    'SYNC_MOUNTED_COLL_AN' => '659',
    'STRUCT_FILE_SYNC_AN' => '660',
    'CLOSE_COLLECTION_AN' => '661',
    'COLL_REPL_AN' => '662',
    'RM_COLL_AN' => '663',
    'GET_MISC_SVR_INFO_AN' => '700',
    'GENERAL_ADMIN_AN' => '701',
    'GEN_QUERY_AN' => '702',
    'AUTH_REQUEST_AN' => '703',
    'AUTH_RESPONSE_AN' => '704',
    'AUTH_CHECK_AN' => '705',
    'MOD_AVU_METADATA_AN' => '706',
    'MOD_ACCESS_CONTROL_AN' => '707',
    'RULE_EXEC_MOD_AN' => '708',
    'GET_TEMP_PASSWORD_AN' => '709',
    'GENERAL_UPDATE_AN' => '710',
    'GSI_AUTH_REQUEST_AN' => '711',
    'OPEN_COLLECTION_AN' => '712',
    'READ_COLLECTION_AN' => '713',
    'PAM_AUTH_REQUEST_AN' => '725',
    'SSL_START_AN' => '1100',
    'SSL_END_AN' => '1101',
);
$GLOBALS['PRODS_API_NUMS_REV'] = array(
    '500' => 'FILE_CREATE_AN',
    '501' => 'FILE_OPEN_AN',
    '502' => 'FILE_WRITE_AN',
    '503' => 'FILE_CLOSE_AN',
    '504' => 'FILE_LSEEK_AN',
    '505' => 'FILE_READ_AN',
    '506' => 'FILE_UNLINK_AN',
    '507' => 'FILE_MKDIR_AN',
    '508' => 'FILE_CHMOD_AN',
    '509' => 'FILE_RMDIR_AN',
    '510' => 'FILE_STAT_AN',
    '511' => 'FILE_FSTAT_AN',
    '512' => 'FILE_FSYNC_AN',
    '513' => 'FILE_STAGE_AN',
    '514' => 'FILE_GET_FS_FREE_SPACE_AN',
    '515' => 'FILE_OPENDIR_AN',
    '516' => 'FILE_CLOSEDIR_AN',
    '517' => 'FILE_READDIR_AN',
    '518' => 'FILE_PUT_AN',
    '519' => 'FILE_GET_AN',
    '520' => 'FILE_CHKSUM_AN',
    '521' => 'CHK_N_V_PATH_PERM_AN',
    '522' => 'FILE_RENAME_AN',
    '523' => 'FILE_TRUNCATE_AN',
    '601' => 'DATA_OBJ_CREATE_AN',
    '602' => 'DATA_OBJ_OPEN_AN',
    '603' => 'DATA_OBJ_READ_AN',
    '604' => 'DATA_OBJ_WRITE_AN',
    '605' => 'DATA_OBJ_CLOSE_AN',
    '606' => 'DATA_OBJ_PUT_AN',
    '607' => 'DATA_PUT_AN',
    '608' => 'DATA_OBJ_GET_AN',
    '609' => 'DATA_GET_AN',
    '610' => 'DATA_OBJ_REPL_AN',
    '611' => 'DATA_COPY_AN',
    '612' => 'DATA_OBJ_LSEEK_AN',
    '613' => 'DATA_OBJ_COPY_AN',
    '614' => 'SIMPLE_QUERY_AN',
    '615' => 'DATA_OBJ_UNLINK_AN',
    '616' => 'COLL_CREATE_AN',
    '617' => 'RM_COLL_OLD_AN',
    '618' => 'REG_COLL_AN',
    '619' => 'REG_DATA_OBJ_AN',
    '620' => 'UNREG_DATA_OBJ_AN',
    '621' => 'REG_REPLICA_AN',
    '622' => 'MOD_DATA_OBJ_META_AN',
    '623' => 'RULE_EXEC_SUBMIT_AN',
    '624' => 'RULE_EXEC_DEL_AN',
    '625' => 'EXEC_MY_RULE_AN',
    '626' => 'OPR_COMPLETE_AN',
    '627' => 'DATA_OBJ_RENAME_AN',
    '628' => 'DATA_OBJ_RSYNC_AN',
    '629' => 'DATA_OBJ_CHKSUM_AN',
    '630' => 'PHY_PATH_REG_AN',
    '631' => 'DATA_OBJ_PHYMV_AN',
    '632' => 'DATA_OBJ_TRIM_AN',
    '633' => 'OBJ_STAT_AN',
    '634' => 'EXEC_CMD_AN',
    '635' => 'SUB_STRUCT_FILE_CREATE_AN',
    '636' => 'SUB_STRUCT_FILE_OPEN_AN',
    '637' => 'SUB_STRUCT_FILE_READ_AN',
    '638' => 'SUB_STRUCT_FILE_WRITE_AN',
    '639' => 'SUB_STRUCT_FILE_CLOSE_AN',
    '640' => 'SUB_STRUCT_FILE_UNLINK_AN',
    '641' => 'SUB_STRUCT_FILE_STAT_AN',
    '642' => 'SUB_STRUCT_FILE_FSTAT_AN',
    '643' => 'SUB_STRUCT_FILE_LSEEK_AN',
    '644' => 'SUB_STRUCT_FILE_RENAME_AN',
    '645' => 'QUERY_SPEC_COLL_AN',
    '646' => 'MOD_COLL_AN',
    '647' => 'SUB_STRUCT_FILE_MKDIR_AN',
    '648' => 'SUB_STRUCT_FILE_RMDIR_AN',
    '649' => 'SUB_STRUCT_FILE_OPENDIR_AN',
    '650' => 'SUB_STRUCT_FILE_READDIR_AN',
    '651' => 'SUB_STRUCT_FILE_CLOSEDIR_AN',
    '652' => 'DATA_OBJ_TRUNCATE_AN',
    '653' => 'SUB_STRUCT_FILE_TRUNCATE_AN',
    '654' => 'GET_XMSG_TICKET_AN',
    '655' => 'SEND_XMSG_AN',
    '656' => 'RCV_XMSG_AN',
    '657' => 'SUB_STRUCT_FILE_GET_AN',
    '658' => 'SUB_STRUCT_FILE_PUT_AN',
    '659' => 'SYNC_MOUNTED_COLL_AN',
    '660' => 'STRUCT_FILE_SYNC_AN',
    '661' => 'CLOSE_COLLECTION_AN',
    '662' => 'COLL_REPL_AN',
    '663' => 'RM_COLL_AN',
    '700' => 'GET_MISC_SVR_INFO_AN',
    '701' => 'GENERAL_ADMIN_AN',
    '702' => 'GEN_QUERY_AN',
    '703' => 'AUTH_REQUEST_AN',
    '704' => 'AUTH_RESPONSE_AN',
    '705' => 'AUTH_CHECK_AN',
    '706' => 'MOD_AVU_METADATA_AN',
    '707' => 'MOD_ACCESS_CONTROL_AN',
    '708' => 'RULE_EXEC_MOD_AN',
    '709' => 'GET_TEMP_PASSWORD_AN',
    '710' => 'GENERAL_UPDATE_AN',
    '711' => 'GSI_AUTH_REQUEST_AN',
    '712' => 'OPEN_COLLECTION_AN',
    '713' => 'READ_COLLECTION_AN',
    '725' => 'PAM_AUTH_REQUEST_AN',
    '1100' => 'SSL_START_AN',
    '1101' => 'SSL_END_AN',
);
?>
