<?php

/* This file is generated by setRodsErrorCodes.php.    Please modify that file if you wish to update the    error codes.            */

$GLOBALS['PRODS_ERR_CODES'] = array(
    'SYS_SOCK_OPEN_ERR' => '-1000',
    'SYS_SOCK_BIND_ERR' => '-2000',
    'SYS_SOCK_ACCEPT_ERR' => '-3000',
    'SYS_HEADER_READ_LEN_ERR' => '-4000',
    'SYS_HEADER_WRITE_LEN_ERR' => '-5000',
    'SYS_HEADER_TPYE_LEN_ERR' => '-6000',
    'SYS_CAUGHT_SIGNAL' => '-7000',
    'SYS_GETSTARTUP_PACK_ERR' => '-8000',
    'SYS_EXCEED_CONNECT_CNT' => '-9000',
    'SYS_USER_NOT_ALLOWED_TO_CONN' => '-10000',
    'SYS_READ_MSG_BODY_INPUT_ERR' => '-11000',
    'SYS_UNMATCHED_API_NUM' => '-12000',
    'SYS_NO_API_PRIV' => '-13000',
    'SYS_API_INPUT_ERR' => '-14000',
    'SYS_PACK_INSTRUCT_FORMAT_ERR' => '-15000',
    'SYS_MALLOC_ERR' => '-16000',
    'SYS_GET_HOSTNAME_ERR' => '-17000',
    'SYS_OUT_OF_FILE_DESC' => '-18000',
    'SYS_FILE_DESC_OUT_OF_RANGE' => '-19000',
    'SYS_UNRECOGNIZED_REMOTE_FLAG' => '-20000',
    'SYS_INVALID_SERVER_HOST' => '-21000',
    'SYS_SVR_TO_SVR_CONNECT_FAILED' => '-22000',
    'SYS_BAD_FILE_DESCRIPTOR' => '-23000',
    'SYS_INTERNAL_NULL_INPUT_ERR' => '-24000',
    'SYS_CONFIG_FILE_ERR' => '-25000',
    'SYS_INVALID_ZONE_NAME' => '-26000',
    'SYS_COPY_LEN_ERR' => '-27000',
    'SYS_PORT_COOKIE_ERR' => '-28000',
    'SYS_KEY_VAL_TABLE_ERR' => '-29000',
    'SYS_INVALID_RESC_TYPE' => '-30000',
    'SYS_INVALID_FILE_PATH' => '-31000',
    'SYS_INVALID_RESC_INPUT' => '-32000',
    'SYS_INVALID_PORTAL_OPR' => '-33000',
    'SYS_PARA_OPR_NO_SUPPORT' => '-34000',
    'SYS_INVALID_OPR_TYPE' => '-35000',
    'SYS_NO_PATH_PERMISSION' => '-36000',
    'SYS_NO_ICAT_SERVER_ERR' => '-37000',
    'SYS_AGENT_INIT_ERR' => '-38000',
    'SYS_PROXYUSER_NO_PRIV' => '-39000',
    'SYS_NO_DATA_OBJ_PERMISSION' => '-40000',
    'SYS_DELETE_DISALLOWED' => '-41000',
    'SYS_OPEN_REI_FILE_ERR' => '-42000',
    'SYS_NO_RCAT_SERVER_ERR' => '-43000',
    'SYS_UNMATCH_PACK_INSTRUCTI_NAME' => '-44000',
    'SYS_SVR_TO_CLI_MSI_NO_EXIST' => '-45000',
    'SYS_COPY_ALREADY_IN_RESC' => '-46000',
    'SYS_RECONN_OPR_MISMATCH' => '-47000',
    'SYS_INPUT_PERM_OUT_OF_RANGE' => '-48000',
    'SYS_FORK_ERROR' => '-49000',
    'SYS_PIPE_ERROR' => '-50000',
    'SYS_EXEC_CMD_STATUS_SZ_ERROR' => '-51000',
    'SYS_PATH_IS_NOT_A_FILE' => '-52000',
    'SYS_UNMATCHED_SPEC_COLL_TYPE' => '-53000',
    'SYS_TOO_MANY_QUERY_RESULT' => '-54000',
    'USER_AUTH_SCHEME_ERR' => '-300000',
    'USER_AUTH_STRING_EMPTY' => '-301000',
    'USER_RODS_HOST_EMPTY' => '-302000',
    'USER_RODS_HOSTNAME_ERR' => '-303000',
    'USER_SOCK_OPEN_ERR' => '-304000',
    'USER_SOCK_CONNECT_ERR' => '-305000',
    'USER_STRLEN_TOOLONG' => '-306000',
    'USER_API_INPUT_ERR' => '-307000',
    'USER_PACKSTRUCT_INPUT_ERR' => '-308000',
    'USER_NO_SUPPORT_ERR' => '-309000',
    'USER_FILE_DOES_NOT_EXIST' => '-310000',
    'USER_FILE_TOO_LARGE' => '-311000',
    'OVERWITE_WITHOUT_FORCE_FLAG' => '-312000',
    'UNMATCHED_KEY_OR_INDEX' => '-313000',
    'USER_CHKSUM_MISMATCH' => '-314000',
    'USER_BAD_KEYWORD_ERR' => '-315000',
    'USER__NULL_INPUT_ERR' => '-316000',
    'USER_INPUT_PATH_ERR' => '-317000',
    'USER_INPUT_OPTION_ERR' => '-318000',
    'USER_INVALID_USERNAME_FORMAT' => '-319000',
    'USER_DIRECT_RESC_INPUT_ERR' => '-320000',
    'USER_NO_RESC_INPUT_ERR' => '-321000',
    'USER_PARAM_LABEL_ERR' => '-322000',
    'USER_PARAM_TYPE_ERR' => '-323000',
    'BASE64_BUFFER_OVERFLOW' => '-324000',
    'BASE64_INVALID_PACKET' => '-325000',
    'USER_MSG_TYPE_NO_SUPPORT' => '-326000',
    'USER_RSYNC_NO_MODE_INPUT_ERR' => '-337000',
    'USER_OPTION_INPUT_ERR' => '-338000',
    'SAME_SRC_DEST_PATHS_ERR' => '-339000',
    'USER_RESTART_FILE_INPUT_ERR' => '-340000',
    'RESTART_OPR_FAILED' => '-341000',
    'BAD_EXEC_CMD_PATH' => '-342000',
    'EXEC_CMD_OUTPUT_TOO_LARGE' => '-343000',
    'EXEC_CMD_ERROR' => '-344000',
    'FILE_INDEX_LOOKUP_ERR' => '-500000',
    'UNIX_FILE_OPEN_ERR' => '-510000',
    'UNIX_FILE_OPEN_ERR_1' => '-510001',
    'UNIX_FILE_OPEN_ERR_2' => '-510002',
    'UNIX_FILE_CREATE_ERR' => '-511000',
    'UNIX_FILE_READ_ERR' => '-512000',
    'UNIX_FILE_WRITE_ERR' => '-513000',
    'UNIX_FILE_CLOSE_ERR' => '-514000',
    'UNIX_FILE_UNLINK_ERR' => '-515000',
    'UNIX_FILE_STAT_ERR' => '-516000',
    'UNIX_FILE_FSTAT_ERR' => '-517000',
    'UNIX_FILE_LSEEK_ERR' => '-518000',
    'UNIX_FILE_FSYNC_ERR' => '-519000',
    'UNIX_FILE_MKDIR_ERR' => '-520000',
    'UNIX_FILE_RMDIR_ERR' => '-521000',
    'UNIX_FILE_OPENDIR_ERR' => '-522000',
    'UNIX_FILE_CLOSEDIR_ERR' => '-523000',
    'UNIX_FILE_READDIR_ERR' => '-524000',
    'UNIX_FILE_STAGE_ERR' => '-525000',
    'UNIX_FILE_GET_FS_FREESPACE_ERR' => '-526000',
    'UNIX_FILE_CHMOD_ERR' => '-527000',
    'UNIX_FILE_RENAME_ERR' => '-528000',
    'CATALOG_NOT_CONNECTED' => '-801000',
    'CAT_ENV_ERR' => '-802000',
    'CAT_CONNECT_ERR' => '-803000',
    'CAT_DISCONNECT_ERR' => '-804000',
    'CAT_CLOSE_ENV_ERR' => '-805000',
    'CAT_SQL_ERR' => '-806000',
    'CAT_GET_ROW_ERR' => '-807000',
    'CAT_NO_ROWS_FOUND' => '-808000',
    'CATALOG_ALREADY_HAS_ITEM_BY_THAT_NAME' => '-809000',
    'CAT_INVALID_RESOURCE_TYPE' => '-810000',
    'CAT_INVALID_RESOURCE_CLASS' => '-811000',
    'CAT_INVALID_RESOURCE_NET_ADDR' => '-812000',
    'CAT_INVALID_RESOURCE_VAULT_PATH' => '-813000',
    'CAT_UNKNOWN_COLLECTION' => '-814000',
    'CAT_INVALID_DATA_TYPE' => '-815000',
    'CAT_INVALID_ARGUMENT' => '-816000',
    'CAT_UNKNOWN_FILE' => '-817000',
    'CAT_NO_ACCESS_PERMISSION' => '-818000',
    'CAT_SUCCESS_BUT_WITH_NO_INFO' => '-819000',
    'CAT_INVALID_USER_TYPE' => '-820000',
    'CAT_COLLECTION_NOT_EMPTY' => '-821000',
    'CAT_TOO_MANY_TABLES' => '-822000',
    'CAT_UNKNOWN_TABLE' => '-823000',
    'CAT_NOT_OPEN' => '-824000',
    'CAT_FAILED_TO_LINK_TABLES' => '-825000',
    'CAT_INVALID_AUTHENTICATION' => '-826000',
    'CAT_INVALID_USER' => '-827000',
    'CAT_INVALID_ZONE' => '-828000',
    'CAT_INVALID_GROUP' => '-829000',
    'CAT_INSUFFICIENT_PRIVILEGE_LEVEL' => '-830000',
    'CAT_INVALID_RESOURCE' => '-831000',
    'CAT_INVALID_CLIENT_USER' => '-832000',
    'CAT_NAME_EXISTS_AS_COLLECTION' => '-833000',
    'CAT_NAME_EXISTS_AS_DATAOBJ' => '-834000',
    'CAT_RESOURCE_NOT_EMPTY' => '-835000',
    'CAT_NOT_A_DATAOBJ_AND_NOT_A_COLLECTION' => '-836000',
    'CAT_RECURSIVE_MOVE' => '-837000',
    'CAT_LAST_REPLICA' => '-838000',
    'CAT_OCI_ERROR' => '-839000',
    'CAT_PASSWORD_EXPIRED' => '-840000',
    'FILE_OPEN_ERR' => '-900000',
    'FILE_READ_ERR' => '-901000',
    'FILE_WRITE_ERR' => '-902000',
    'PASSWORD_EXCEEDS_MAX_SIZE' => '-903000',
    'ENVIRONMENT_VAR_HOME_NOT_DEFINED' => '-904000',
    'UNABLE_TO_STAT_FILE' => '-905000',
    'AUTH_FILE_NOT_ENCRYPTED' => '-906000',
    'AUTH_FILE_DOES_NOT_EXIST' => '-907000',
    'UNLINK_FAILED' => '-908000',
    'NO_PASSWORD_ENTERED' => '-909000',
    'OBJPATH_EMPTY_IN_STRUCT_ERR' => '-1000000',
    'RESCNAME_EMPTY_IN_STRUCT_ERR' => '-1001000',
    'DATATYPE_EMPTY_IN_STRUCT_ERR' => '-1002000',
    'DATASIZE_EMPTY_IN_STRUCT_ERR' => '-1003000',
    'CHKSUM_EMPTY_IN_STRUCT_ERR' => '-1004000',
    'VERSION_EMPTY_IN_STRUCT_ERR' => '-1005000',
    'FILEPATH_EMPTY_IN_STRUCT_ERR' => '-1006000',
    'REPLNUM_EMPTY_IN_STRUCT_ERR' => '-1007000',
    'REPLSTATUS_EMPTY_IN_STRUCT_ERR' => '-1008000',
    'DATAOWNER_EMPTY_IN_STRUCT_ERR' => '-1009000',
    'DATAOWNERZONE_EMPTY_IN_STRUCT_ERR' => '-1010000',
    'DATAEXPIRY_EMPTY_IN_STRUCT_ERR' => '-1011000',
    'DATACOMMENTS_EMPTY_IN_STRUCT_ERR' => '-1012000',
    'DATACREATE_EMPTY_IN_STRUCT_ERR' => '-1013000',
    'DATAMODIFY_EMPTY_IN_STRUCT_ERR' => '-1014000',
    'DATAACCESS_EMPTY_IN_STRUCT_ERR' => '-1015000',
    'DATAACCESSINX_EMPTY_IN_STRUCT_ERR' => '-1016000',
    'NO_RULE_FOUND_ERR' => '-1017000',
    'NO_MORE_RULES_ERR' => '-1018000',
    'UNMATCHED_ACTION_ERR' => '-1019000',
    'RULES_FILE_READ_ERROR' => '-1020000',
    'ACTION_ARG_COUNT_MISMATCH' => '-1021000',
    'MAX_NUM_OF_ARGS_IN_ACTION_EXCEEDED' => '-1022000',
    'UNKNOWN_PARAM_IN_RULE_ERR' => '-1023000',
    'DESTRESCNAME_EMPTY_IN_STRUCT_ERR' => '-1024000',
    'BACKUPRESCNAME_EMPTY_IN_STRUCT_ERR' => '-1025000',
    'DATAID_EMPTY_IN_STRUCT_ERR' => '-1026000',
    'COLLID_EMPTY_IN_STRUCT_ERR' => '-1027000',
    'RESCGROUPNAME_EMPTY_IN_STRUCT_ERR' => '-1028000',
    'STATUSSTRING_EMPTY_IN_STRUCT_ERR' => '-1029000',
    'DATAMAPID_EMPTY_IN_STRUCT_ERR' => '-1030000',
    'USERNAMECLIENT_EMPTY_IN_STRUCT_ERR' => '-1031000',
    'RODSZONECLIENT_EMPTY_IN_STRUCT_ERR' => '-1032000',
    'USERTYPECLIENT_EMPTY_IN_STRUCT_ERR' => '-1033000',
    'HOSTCLIENT_EMPTY_IN_STRUCT_ERR' => '-1034000',
    'AUTHSTRCLIENT_EMPTY_IN_STRUCT_ERR' => '-1035000',
    'USERAUTHSCHEMECLIENT_EMPTY_IN_STRUCT_ERR' => '-1036000',
    'USERINFOCLIENT_EMPTY_IN_STRUCT_ERR' => '-1037000',
    'USERCOMMENTCLIENT_EMPTY_IN_STRUCT_ERR' => '-1038000',
    'USERCREATECLIENT_EMPTY_IN_STRUCT_ERR' => '-1039000',
    'USERMODIFYCLIENT_EMPTY_IN_STRUCT_ERR' => '-1040000',
    'USERNAMEPROXY_EMPTY_IN_STRUCT_ERR' => '-1041000',
    'RODSZONEPROXY_EMPTY_IN_STRUCT_ERR' => '-1042000',
    'USERTYPEPROXY_EMPTY_IN_STRUCT_ERR' => '-1043000',
    'HOSTPROXY_EMPTY_IN_STRUCT_ERR' => '-1044000',
    'AUTHSTRPROXY_EMPTY_IN_STRUCT_ERR' => '-1045000',
    'USERAUTHSCHEMEPROXY_EMPTY_IN_STRUCT_ERR' => '-1046000',
    'USERINFOPROXY_EMPTY_IN_STRUCT_ERR' => '-1047000',
    'USERCOMMENTPROXY_EMPTY_IN_STRUCT_ERR' => '-1048000',
    'USERCREATEPROXY_EMPTY_IN_STRUCT_ERR' => '-1049000',
    'USERMODIFYPROXY_EMPTY_IN_STRUCT_ERR' => '-1050000',
    'COLLNAME_EMPTY_IN_STRUCT_ERR' => '-1051000',
    'COLLPARENTNAME_EMPTY_IN_STRUCT_ERR' => '-1052000',
    'COLLOWNERNAME_EMPTY_IN_STRUCT_ERR' => '-1053000',
    'COLLOWNERZONE_EMPTY_IN_STRUCT_ERR' => '-1054000',
    'COLLEXPIRY_EMPTY_IN_STRUCT_ERR' => '-1055000',
    'COLLCOMMENTS_EMPTY_IN_STRUCT_ERR' => '-1056000',
    'COLLCREATE_EMPTY_IN_STRUCT_ERR' => '-1057000',
    'COLLMODIFY_EMPTY_IN_STRUCT_ERR' => '-1058000',
    'COLLACCESS_EMPTY_IN_STRUCT_ERR' => '-1059000',
    'COLLACCESSINX_EMPTY_IN_STRUCT_ERR' => '-1060000',
    'COLLMAPID_EMPTY_IN_STRUCT_ERR' => '-1062000',
    'COLLINHERITANCE_EMPTY_IN_STRUCT_ERR' => '-1063000',
    'RESCZONE_EMPTY_IN_STRUCT_ERR' => '-1065000',
    'RESCLOC_EMPTY_IN_STRUCT_ERR' => '-1066000',
    'RESCTYPE_EMPTY_IN_STRUCT_ERR' => '-1067000',
    'RESCTYPEINX_EMPTY_IN_STRUCT_ERR' => '-1068000',
    'RESCCLASS_EMPTY_IN_STRUCT_ERR' => '-1069000',
    'RESCCLASSINX_EMPTY_IN_STRUCT_ERR' => '-1070000',
    'RESCVAULTPATH_EMPTY_IN_STRUCT_ERR' => '-1071000',
    'NUMOPEN_ORTS_EMPTY_IN_STRUCT_ERR' => '-1072000',
    'PARAOPR_EMPTY_IN_STRUCT_ERR' => '-1073000',
    'RESCID_EMPTY_IN_STRUCT_ERR' => '-1074000',
    'GATEWAYADDR_EMPTY_IN_STRUCT_ERR' => '-1075000',
    'RESCMAX_BJSIZE_EMPTY_IN_STRUCT_ERR' => '-1076000',
    'FREESPACE_EMPTY_IN_STRUCT_ERR' => '-1077000',
    'FREESPACETIME_EMPTY_IN_STRUCT_ERR' => '-1078000',
    'FREESPACETIMESTAMP_EMPTY_IN_STRUCT_ERR' => '-1079000',
    'RESCINFO_EMPTY_IN_STRUCT_ERR' => '-1080000',
    'RESCCOMMENTS_EMPTY_IN_STRUCT_ERR' => '-1081000',
    'RESCCREATE_EMPTY_IN_STRUCT_ERR' => '-1082000',
    'RESCMODIFY_EMPTY_IN_STRUCT_ERR' => '-1083000',
    'INPUT_ARG_NOT_WELL_FORMED_ERR' => '-1084000',
    'INPUT_ARG_OUT_OF_ARGC_RANGE_ERR' => '-1085000',
    'INSUFFICIENT_INPUT_ARG_ERR' => '-1086000',
    'INPUT_ARG_DOES_NOT_MATCH_ERR' => '-1087000',
    'RETRY_WITHOUT_RECOVERY_ERR' => '-1088000',
    'CUT_ACTION_PROCESSED_ERR' => '-1089000',
    'ACTION_FAILED_ERR' => '-1090000',
    'FAIL_ACTION_ENCOUNTERED_ERR' => '-1091000',
    'VARIABLE_NAME_TOO_LONG_ERR' => '-1092000',
    'UNKNOWN_VARIABLE_MAP_ERR' => '-1093000',
    'UNDEFINED_VARIABLE_MAP_ERR' => '-1094000',
    'NULL_VALUE_ERR' => '-1095000',
    'DVARMAP_FILE_READ_ERROR' => '-1096000',
    'NO_RULE_OR_MSI_FUNCTION_FOUND_ERR' => '-1097000',
    'FILE_CREATE_ERROR' => '-1098000',
    'FMAP_FILE_READ_ERROR' => '-1099000',
    'DATE_FORMAT_ERR' => '-1100000',
    'RULE_FAILED_ERR' => '-1101000',
    'NO_MICROSERVICE_FOUND_ERR' => '-1102000',
    'INVALID_REGEXP' => '-1103000',
    'INVALID_OBJECT_NAME' => '-1104000',
    'INVALID_OBJECT_TYPE' => '-1105000',
    'NO_VALUES_FOUND' => '-1106000',
    'NO_COLUMN_NAME_FOUND' => '-1107000',
    'SYS_NULL_INPUT' => '-99999996',
    'SYS_HANDLER_DONE_WITH_ERROR' => '-99999997',
    'SYS_HANDLER_DONE_NO_ERROR' => '-99999998',
    'SYS_NO_HANDLER_REPLY_MSG' => '-99999999',
    'GENERAL_PRODS_ERR' => '-3000000',
    'PERR_INTERNAL_ERR' => '-3100000',
    'PERR_UNEXPECTED_PACKET_FORMAT' => '-3101000',
    'PERR_PATH_DOES_NOT_EXISTS' => '-3102000',
    'PERR_UNSUPPORTED_PROTOCOL_SCHEME' => '-3103000',
    'PERR_USER_INPUT_ERROR' => '-3104000',
    'PERR_USER_INPUT_PATH_ERROR' => '-3105000',
    'PERR_CONN_NOT_ACTIVE' => '-3106000',
    'SSL_NOT_BUILT_INTO_CLIENT' => '-2100000',
    'SSL_NOT_BUILT_INTO_SERVER' => '-2101000',
    'SSL_INIT_ERROR' => '-2102000',
    'SSL_HANDSHAKE_ERROR' => '-2103000',
    'SSL_SHUTDOWN_ERROR' => '-2104000',
    'SSL_CERT_ERROR' => '-2105000',
    'PAM_AUTH_NOT_BUILT_INTO_CLIENT' => '-991000',
    'PAM_AUTH_NOT_BUILT_INTO_SERVER' => '-992000',
    'PAM_AUTH_PASSWORD_FAILED' => '-993000',
    'PAM_AUTH_PASSWORD_INVALID_TTL' => '-994000',
);
$GLOBALS['PRODS_ERR_CODES_REV'] = array(
    '-1000' => 'SYS_SOCK_OPEN_ERR',
    '-2000' => 'SYS_SOCK_BIND_ERR',
    '-3000' => 'SYS_SOCK_ACCEPT_ERR',
    '-4000' => 'SYS_HEADER_READ_LEN_ERR',
    '-5000' => 'SYS_HEADER_WRITE_LEN_ERR',
    '-6000' => 'SYS_HEADER_TPYE_LEN_ERR',
    '-7000' => 'SYS_CAUGHT_SIGNAL',
    '-8000' => 'SYS_GETSTARTUP_PACK_ERR',
    '-9000' => 'SYS_EXCEED_CONNECT_CNT',
    '-10000' => 'SYS_USER_NOT_ALLOWED_TO_CONN',
    '-11000' => 'SYS_READ_MSG_BODY_INPUT_ERR',
    '-12000' => 'SYS_UNMATCHED_API_NUM',
    '-13000' => 'SYS_NO_API_PRIV',
    '-14000' => 'SYS_API_INPUT_ERR',
    '-15000' => 'SYS_PACK_INSTRUCT_FORMAT_ERR',
    '-16000' => 'SYS_MALLOC_ERR',
    '-17000' => 'SYS_GET_HOSTNAME_ERR',
    '-18000' => 'SYS_OUT_OF_FILE_DESC',
    '-19000' => 'SYS_FILE_DESC_OUT_OF_RANGE',
    '-20000' => 'SYS_UNRECOGNIZED_REMOTE_FLAG',
    '-21000' => 'SYS_INVALID_SERVER_HOST',
    '-22000' => 'SYS_SVR_TO_SVR_CONNECT_FAILED',
    '-23000' => 'SYS_BAD_FILE_DESCRIPTOR',
    '-24000' => 'SYS_INTERNAL_NULL_INPUT_ERR',
    '-25000' => 'SYS_CONFIG_FILE_ERR',
    '-26000' => 'SYS_INVALID_ZONE_NAME',
    '-27000' => 'SYS_COPY_LEN_ERR',
    '-28000' => 'SYS_PORT_COOKIE_ERR',
    '-29000' => 'SYS_KEY_VAL_TABLE_ERR',
    '-30000' => 'SYS_INVALID_RESC_TYPE',
    '-31000' => 'SYS_INVALID_FILE_PATH',
    '-32000' => 'SYS_INVALID_RESC_INPUT',
    '-33000' => 'SYS_INVALID_PORTAL_OPR',
    '-34000' => 'SYS_PARA_OPR_NO_SUPPORT',
    '-35000' => 'SYS_INVALID_OPR_TYPE',
    '-36000' => 'SYS_NO_PATH_PERMISSION',
    '-37000' => 'SYS_NO_ICAT_SERVER_ERR',
    '-38000' => 'SYS_AGENT_INIT_ERR',
    '-39000' => 'SYS_PROXYUSER_NO_PRIV',
    '-40000' => 'SYS_NO_DATA_OBJ_PERMISSION',
    '-41000' => 'SYS_DELETE_DISALLOWED',
    '-42000' => 'SYS_OPEN_REI_FILE_ERR',
    '-43000' => 'SYS_NO_RCAT_SERVER_ERR',
    '-44000' => 'SYS_UNMATCH_PACK_INSTRUCTI_NAME',
    '-45000' => 'SYS_SVR_TO_CLI_MSI_NO_EXIST',
    '-46000' => 'SYS_COPY_ALREADY_IN_RESC',
    '-47000' => 'SYS_RECONN_OPR_MISMATCH',
    '-48000' => 'SYS_INPUT_PERM_OUT_OF_RANGE',
    '-49000' => 'SYS_FORK_ERROR',
    '-50000' => 'SYS_PIPE_ERROR',
    '-51000' => 'SYS_EXEC_CMD_STATUS_SZ_ERROR',
    '-52000' => 'SYS_PATH_IS_NOT_A_FILE',
    '-53000' => 'SYS_UNMATCHED_SPEC_COLL_TYPE',
    '-54000' => 'SYS_TOO_MANY_QUERY_RESULT',
    '-300000' => 'USER_AUTH_SCHEME_ERR',
    '-301000' => 'USER_AUTH_STRING_EMPTY',
    '-302000' => 'USER_RODS_HOST_EMPTY',
    '-303000' => 'USER_RODS_HOSTNAME_ERR',
    '-304000' => 'USER_SOCK_OPEN_ERR',
    '-305000' => 'USER_SOCK_CONNECT_ERR',
    '-306000' => 'USER_STRLEN_TOOLONG',
    '-307000' => 'USER_API_INPUT_ERR',
    '-308000' => 'USER_PACKSTRUCT_INPUT_ERR',
    '-309000' => 'USER_NO_SUPPORT_ERR',
    '-310000' => 'USER_FILE_DOES_NOT_EXIST',
    '-311000' => 'USER_FILE_TOO_LARGE',
    '-312000' => 'OVERWITE_WITHOUT_FORCE_FLAG',
    '-313000' => 'UNMATCHED_KEY_OR_INDEX',
    '-314000' => 'USER_CHKSUM_MISMATCH',
    '-315000' => 'USER_BAD_KEYWORD_ERR',
    '-316000' => 'USER__NULL_INPUT_ERR',
    '-317000' => 'USER_INPUT_PATH_ERR',
    '-318000' => 'USER_INPUT_OPTION_ERR',
    '-319000' => 'USER_INVALID_USERNAME_FORMAT',
    '-320000' => 'USER_DIRECT_RESC_INPUT_ERR',
    '-321000' => 'USER_NO_RESC_INPUT_ERR',
    '-322000' => 'USER_PARAM_LABEL_ERR',
    '-323000' => 'USER_PARAM_TYPE_ERR',
    '-324000' => 'BASE64_BUFFER_OVERFLOW',
    '-325000' => 'BASE64_INVALID_PACKET',
    '-326000' => 'USER_MSG_TYPE_NO_SUPPORT',
    '-337000' => 'USER_RSYNC_NO_MODE_INPUT_ERR',
    '-338000' => 'USER_OPTION_INPUT_ERR',
    '-339000' => 'SAME_SRC_DEST_PATHS_ERR',
    '-340000' => 'USER_RESTART_FILE_INPUT_ERR',
    '-341000' => 'RESTART_OPR_FAILED',
    '-342000' => 'BAD_EXEC_CMD_PATH',
    '-343000' => 'EXEC_CMD_OUTPUT_TOO_LARGE',
    '-344000' => 'EXEC_CMD_ERROR',
    '-500000' => 'FILE_INDEX_LOOKUP_ERR',
    '-510000' => 'UNIX_FILE_OPEN_ERR',
    '-510001' => 'UNIX_FILE_OPEN_ERR_1',
    '-510002' => 'UNIX_FILE_OPEN_ERR_2',
    '-511000' => 'UNIX_FILE_CREATE_ERR',
    '-512000' => 'UNIX_FILE_READ_ERR',
    '-513000' => 'UNIX_FILE_WRITE_ERR',
    '-514000' => 'UNIX_FILE_CLOSE_ERR',
    '-515000' => 'UNIX_FILE_UNLINK_ERR',
    '-516000' => 'UNIX_FILE_STAT_ERR',
    '-517000' => 'UNIX_FILE_FSTAT_ERR',
    '-518000' => 'UNIX_FILE_LSEEK_ERR',
    '-519000' => 'UNIX_FILE_FSYNC_ERR',
    '-520000' => 'UNIX_FILE_MKDIR_ERR',
    '-521000' => 'UNIX_FILE_RMDIR_ERR',
    '-522000' => 'UNIX_FILE_OPENDIR_ERR',
    '-523000' => 'UNIX_FILE_CLOSEDIR_ERR',
    '-524000' => 'UNIX_FILE_READDIR_ERR',
    '-525000' => 'UNIX_FILE_STAGE_ERR',
    '-526000' => 'UNIX_FILE_GET_FS_FREESPACE_ERR',
    '-527000' => 'UNIX_FILE_CHMOD_ERR',
    '-528000' => 'UNIX_FILE_RENAME_ERR',
    '-801000' => 'CATALOG_NOT_CONNECTED',
    '-802000' => 'CAT_ENV_ERR',
    '-803000' => 'CAT_CONNECT_ERR',
    '-804000' => 'CAT_DISCONNECT_ERR',
    '-805000' => 'CAT_CLOSE_ENV_ERR',
    '-806000' => 'CAT_SQL_ERR',
    '-807000' => 'CAT_GET_ROW_ERR',
    '-808000' => 'CAT_NO_ROWS_FOUND',
    '-809000' => 'CATALOG_ALREADY_HAS_ITEM_BY_THAT_NAME',
    '-810000' => 'CAT_INVALID_RESOURCE_TYPE',
    '-811000' => 'CAT_INVALID_RESOURCE_CLASS',
    '-812000' => 'CAT_INVALID_RESOURCE_NET_ADDR',
    '-813000' => 'CAT_INVALID_RESOURCE_VAULT_PATH',
    '-814000' => 'CAT_UNKNOWN_COLLECTION',
    '-815000' => 'CAT_INVALID_DATA_TYPE',
    '-816000' => 'CAT_INVALID_ARGUMENT',
    '-817000' => 'CAT_UNKNOWN_FILE',
    '-818000' => 'CAT_NO_ACCESS_PERMISSION',
    '-819000' => 'CAT_SUCCESS_BUT_WITH_NO_INFO',
    '-820000' => 'CAT_INVALID_USER_TYPE',
    '-821000' => 'CAT_COLLECTION_NOT_EMPTY',
    '-822000' => 'CAT_TOO_MANY_TABLES',
    '-823000' => 'CAT_UNKNOWN_TABLE',
    '-824000' => 'CAT_NOT_OPEN',
    '-825000' => 'CAT_FAILED_TO_LINK_TABLES',
    '-826000' => 'CAT_INVALID_AUTHENTICATION',
    '-827000' => 'CAT_INVALID_USER',
    '-828000' => 'CAT_INVALID_ZONE',
    '-829000' => 'CAT_INVALID_GROUP',
    '-830000' => 'CAT_INSUFFICIENT_PRIVILEGE_LEVEL',
    '-831000' => 'CAT_INVALID_RESOURCE',
    '-832000' => 'CAT_INVALID_CLIENT_USER',
    '-833000' => 'CAT_NAME_EXISTS_AS_COLLECTION',
    '-834000' => 'CAT_NAME_EXISTS_AS_DATAOBJ',
    '-835000' => 'CAT_RESOURCE_NOT_EMPTY',
    '-836000' => 'CAT_NOT_A_DATAOBJ_AND_NOT_A_COLLECTION',
    '-837000' => 'CAT_RECURSIVE_MOVE',
    '-838000' => 'CAT_LAST_REPLICA',
    '-839000' => 'CAT_OCI_ERROR',
    '-840000' => 'CAT_PASSWORD_EXPIRED',
    '-900000' => 'FILE_OPEN_ERR',
    '-901000' => 'FILE_READ_ERR',
    '-902000' => 'FILE_WRITE_ERR',
    '-903000' => 'PASSWORD_EXCEEDS_MAX_SIZE',
    '-904000' => 'ENVIRONMENT_VAR_HOME_NOT_DEFINED',
    '-905000' => 'UNABLE_TO_STAT_FILE',
    '-906000' => 'AUTH_FILE_NOT_ENCRYPTED',
    '-907000' => 'AUTH_FILE_DOES_NOT_EXIST',
    '-908000' => 'UNLINK_FAILED',
    '-909000' => 'NO_PASSWORD_ENTERED',
    '-1000000' => 'OBJPATH_EMPTY_IN_STRUCT_ERR',
    '-1001000' => 'RESCNAME_EMPTY_IN_STRUCT_ERR',
    '-1002000' => 'DATATYPE_EMPTY_IN_STRUCT_ERR',
    '-1003000' => 'DATASIZE_EMPTY_IN_STRUCT_ERR',
    '-1004000' => 'CHKSUM_EMPTY_IN_STRUCT_ERR',
    '-1005000' => 'VERSION_EMPTY_IN_STRUCT_ERR',
    '-1006000' => 'FILEPATH_EMPTY_IN_STRUCT_ERR',
    '-1007000' => 'REPLNUM_EMPTY_IN_STRUCT_ERR',
    '-1008000' => 'REPLSTATUS_EMPTY_IN_STRUCT_ERR',
    '-1009000' => 'DATAOWNER_EMPTY_IN_STRUCT_ERR',
    '-1010000' => 'DATAOWNERZONE_EMPTY_IN_STRUCT_ERR',
    '-1011000' => 'DATAEXPIRY_EMPTY_IN_STRUCT_ERR',
    '-1012000' => 'DATACOMMENTS_EMPTY_IN_STRUCT_ERR',
    '-1013000' => 'DATACREATE_EMPTY_IN_STRUCT_ERR',
    '-1014000' => 'DATAMODIFY_EMPTY_IN_STRUCT_ERR',
    '-1015000' => 'DATAACCESS_EMPTY_IN_STRUCT_ERR',
    '-1016000' => 'DATAACCESSINX_EMPTY_IN_STRUCT_ERR',
    '-1017000' => 'NO_RULE_FOUND_ERR',
    '-1018000' => 'NO_MORE_RULES_ERR',
    '-1019000' => 'UNMATCHED_ACTION_ERR',
    '-1020000' => 'RULES_FILE_READ_ERROR',
    '-1021000' => 'ACTION_ARG_COUNT_MISMATCH',
    '-1022000' => 'MAX_NUM_OF_ARGS_IN_ACTION_EXCEEDED',
    '-1023000' => 'UNKNOWN_PARAM_IN_RULE_ERR',
    '-1024000' => 'DESTRESCNAME_EMPTY_IN_STRUCT_ERR',
    '-1025000' => 'BACKUPRESCNAME_EMPTY_IN_STRUCT_ERR',
    '-1026000' => 'DATAID_EMPTY_IN_STRUCT_ERR',
    '-1027000' => 'COLLID_EMPTY_IN_STRUCT_ERR',
    '-1028000' => 'RESCGROUPNAME_EMPTY_IN_STRUCT_ERR',
    '-1029000' => 'STATUSSTRING_EMPTY_IN_STRUCT_ERR',
    '-1030000' => 'DATAMAPID_EMPTY_IN_STRUCT_ERR',
    '-1031000' => 'USERNAMECLIENT_EMPTY_IN_STRUCT_ERR',
    '-1032000' => 'RODSZONECLIENT_EMPTY_IN_STRUCT_ERR',
    '-1033000' => 'USERTYPECLIENT_EMPTY_IN_STRUCT_ERR',
    '-1034000' => 'HOSTCLIENT_EMPTY_IN_STRUCT_ERR',
    '-1035000' => 'AUTHSTRCLIENT_EMPTY_IN_STRUCT_ERR',
    '-1036000' => 'USERAUTHSCHEMECLIENT_EMPTY_IN_STRUCT_ERR',
    '-1037000' => 'USERINFOCLIENT_EMPTY_IN_STRUCT_ERR',
    '-1038000' => 'USERCOMMENTCLIENT_EMPTY_IN_STRUCT_ERR',
    '-1039000' => 'USERCREATECLIENT_EMPTY_IN_STRUCT_ERR',
    '-1040000' => 'USERMODIFYCLIENT_EMPTY_IN_STRUCT_ERR',
    '-1041000' => 'USERNAMEPROXY_EMPTY_IN_STRUCT_ERR',
    '-1042000' => 'RODSZONEPROXY_EMPTY_IN_STRUCT_ERR',
    '-1043000' => 'USERTYPEPROXY_EMPTY_IN_STRUCT_ERR',
    '-1044000' => 'HOSTPROXY_EMPTY_IN_STRUCT_ERR',
    '-1045000' => 'AUTHSTRPROXY_EMPTY_IN_STRUCT_ERR',
    '-1046000' => 'USERAUTHSCHEMEPROXY_EMPTY_IN_STRUCT_ERR',
    '-1047000' => 'USERINFOPROXY_EMPTY_IN_STRUCT_ERR',
    '-1048000' => 'USERCOMMENTPROXY_EMPTY_IN_STRUCT_ERR',
    '-1049000' => 'USERCREATEPROXY_EMPTY_IN_STRUCT_ERR',
    '-1050000' => 'USERMODIFYPROXY_EMPTY_IN_STRUCT_ERR',
    '-1051000' => 'COLLNAME_EMPTY_IN_STRUCT_ERR',
    '-1052000' => 'COLLPARENTNAME_EMPTY_IN_STRUCT_ERR',
    '-1053000' => 'COLLOWNERNAME_EMPTY_IN_STRUCT_ERR',
    '-1054000' => 'COLLOWNERZONE_EMPTY_IN_STRUCT_ERR',
    '-1055000' => 'COLLEXPIRY_EMPTY_IN_STRUCT_ERR',
    '-1056000' => 'COLLCOMMENTS_EMPTY_IN_STRUCT_ERR',
    '-1057000' => 'COLLCREATE_EMPTY_IN_STRUCT_ERR',
    '-1058000' => 'COLLMODIFY_EMPTY_IN_STRUCT_ERR',
    '-1059000' => 'COLLACCESS_EMPTY_IN_STRUCT_ERR',
    '-1060000' => 'COLLACCESSINX_EMPTY_IN_STRUCT_ERR',
    '-1062000' => 'COLLMAPID_EMPTY_IN_STRUCT_ERR',
    '-1063000' => 'COLLINHERITANCE_EMPTY_IN_STRUCT_ERR',
    '-1065000' => 'RESCZONE_EMPTY_IN_STRUCT_ERR',
    '-1066000' => 'RESCLOC_EMPTY_IN_STRUCT_ERR',
    '-1067000' => 'RESCTYPE_EMPTY_IN_STRUCT_ERR',
    '-1068000' => 'RESCTYPEINX_EMPTY_IN_STRUCT_ERR',
    '-1069000' => 'RESCCLASS_EMPTY_IN_STRUCT_ERR',
    '-1070000' => 'RESCCLASSINX_EMPTY_IN_STRUCT_ERR',
    '-1071000' => 'RESCVAULTPATH_EMPTY_IN_STRUCT_ERR',
    '-1072000' => 'NUMOPEN_ORTS_EMPTY_IN_STRUCT_ERR',
    '-1073000' => 'PARAOPR_EMPTY_IN_STRUCT_ERR',
    '-1074000' => 'RESCID_EMPTY_IN_STRUCT_ERR',
    '-1075000' => 'GATEWAYADDR_EMPTY_IN_STRUCT_ERR',
    '-1076000' => 'RESCMAX_BJSIZE_EMPTY_IN_STRUCT_ERR',
    '-1077000' => 'FREESPACE_EMPTY_IN_STRUCT_ERR',
    '-1078000' => 'FREESPACETIME_EMPTY_IN_STRUCT_ERR',
    '-1079000' => 'FREESPACETIMESTAMP_EMPTY_IN_STRUCT_ERR',
    '-1080000' => 'RESCINFO_EMPTY_IN_STRUCT_ERR',
    '-1081000' => 'RESCCOMMENTS_EMPTY_IN_STRUCT_ERR',
    '-1082000' => 'RESCCREATE_EMPTY_IN_STRUCT_ERR',
    '-1083000' => 'RESCMODIFY_EMPTY_IN_STRUCT_ERR',
    '-1084000' => 'INPUT_ARG_NOT_WELL_FORMED_ERR',
    '-1085000' => 'INPUT_ARG_OUT_OF_ARGC_RANGE_ERR',
    '-1086000' => 'INSUFFICIENT_INPUT_ARG_ERR',
    '-1087000' => 'INPUT_ARG_DOES_NOT_MATCH_ERR',
    '-1088000' => 'RETRY_WITHOUT_RECOVERY_ERR',
    '-1089000' => 'CUT_ACTION_PROCESSED_ERR',
    '-1090000' => 'ACTION_FAILED_ERR',
    '-1091000' => 'FAIL_ACTION_ENCOUNTERED_ERR',
    '-1092000' => 'VARIABLE_NAME_TOO_LONG_ERR',
    '-1093000' => 'UNKNOWN_VARIABLE_MAP_ERR',
    '-1094000' => 'UNDEFINED_VARIABLE_MAP_ERR',
    '-1095000' => 'NULL_VALUE_ERR',
    '-1096000' => 'DVARMAP_FILE_READ_ERROR',
    '-1097000' => 'NO_RULE_OR_MSI_FUNCTION_FOUND_ERR',
    '-1098000' => 'FILE_CREATE_ERROR',
    '-1099000' => 'FMAP_FILE_READ_ERROR',
    '-1100000' => 'DATE_FORMAT_ERR',
    '-1101000' => 'RULE_FAILED_ERR',
    '-1102000' => 'NO_MICROSERVICE_FOUND_ERR',
    '-1103000' => 'INVALID_REGEXP',
    '-1104000' => 'INVALID_OBJECT_NAME',
    '-1105000' => 'INVALID_OBJECT_TYPE',
    '-1106000' => 'NO_VALUES_FOUND',
    '-1107000' => 'NO_COLUMN_NAME_FOUND',
    '-99999996' => 'SYS_NULL_INPUT',
    '-99999997' => 'SYS_HANDLER_DONE_WITH_ERROR',
    '-99999998' => 'SYS_HANDLER_DONE_NO_ERROR',
    '-99999999' => 'SYS_NO_HANDLER_REPLY_MSG',
    '-3000000' => 'GENERAL_PRODS_ERR',
    '-3100000' => 'PERR_INTERNAL_ERR',
    '-3101000' => 'PERR_UNEXPECTED_PACKET_FORMAT',
    '-3102000' => 'PERR_PATH_DOES_NOT_EXISTS',
    '-3103000' => 'PERR_UNSUPPORTED_PROTOCOL_SCHEME',
    '-3104000' => 'PERR_USER_INPUT_ERROR',
    '-3105000' => 'PERR_USER_INPUT_PATH_ERROR',
    '-3106000' => 'PERR_CONN_NOT_ACTIVE',
    '-2100000' => 'SSL_NOT_BUILT_INTO_CLIENT',
    '-2101000' => 'SSL_NOT_BUILT_INTO_SERVER',
    '-2102000' => 'SSL_INIT_ERROR',
    '-2103000' => 'SSL_HANDSHAKE_ERROR',
    '-2104000' => 'SSL_SHUTDOWN_ERROR',
    '-2105000' => 'SSL_CERT_ERROR',
    '-991000' => 'PAM_AUTH_NOT_BUILT_INTO_CLIENT',
    '-992000' => 'PAM_AUTH_NOT_BUILT_INTO_SERVER',
    '-993000' => 'PAM_AUTH_PASSWORD_FAILED',
    '-994000' => 'PAM_AUTH_PASSWORD_INVALID_TTL',
);
?>
