<?php
/* This file is generated by setRodsGenQueryKeyWd.php   Please modify that file if you wish to update the    Gen Query keywords.            */
$GLOBALS['PRODS_GENQUE_KEYWD'] = array(
    'ALL_KW' => "all",
    'COPIES_KW' => "copies",
    'EXEC_LOCALLY_KW' => "execLocally",
    'FORCE_FLAG_KW' => "forceFlag",
    'CLI_IN_SVR_FIREWALL_KW' => "cliInSvrFirewall",
    'REG_CHKSUM_KW' => "regChksum",
    'VERIFY_CHKSUM_KW' => "verifyChksum",
    'VERIFY_BY_SIZE_KW' => "verifyBySize",
    'OBJ_PATH_KW' => "objPath",
    'RESC_NAME_KW' => "rescName",
    'DEST_RESC_NAME_KW' => "destRescName",
    'BACKUP_RESC_NAME_KW' => "backupRescName",
    'DATA_TYPE_KW' => "dataType",
    'DATA_SIZE_KW' => "dataSize",
    'CHKSUM_KW' => "chksum",
    'VERSION_KW' => "version",
    'FILE_PATH_KW' => "filePath",
    'REPL_NUM_KW' => "replNum",
    'REPL_STATUS_KW' => "replStatus",
    'ALL_REPL_STATUS_KW' => "allReplStatus",
    'DATA_INCLUDED_KW' => "dataIncluded",
    'DATA_OWNER_KW' => "dataOwner",
    'DATA_OWNER_ZONE_KW' => "dataOwnerZone",
    'DATA_EXPIRY_KW' => "dataExpiry",
    'DATA_COMMENTS_KW' => "dataComments",
    'DATA_CREATE_KW' => "dataCreate",
    'DATA_MODIFY_KW' => "dataModify",
    'DATA_ACCESS_KW' => "dataAccess",
    'DATA_ACCESS_INX_KW' => "dataAccessInx",
    'NO_OPEN_FLAG_KW' => "noOpenFlag",
    'STREAMING_KW' => "streaming",
    'DATA_ID_KW' => "dataId",
    'COLL_ID_KW' => "collId",
    'RESC_GROUP_NAME_KW' => "rescGroupName",
    'STATUS_STRING_KW' => "statusString",
    'DATA_MAP_ID_KW' => "dataMapId",
    'NO_PARA_OP_KW' => "noParaOpr",
    'LOCAL_PATH_KW' => "localPath",
    'RSYNC_MODE_KW' => "rsyncMode",
    'RSYNC_DEST_PATH_KW' => "rsyncDestPath",
    'RSYNC_CHKSUM_KW' => "rsyncChksum",
    'CHKSUM_ALL_KW' => "ChksumAll",
    'FORCE_CHKSUM_KW' => "forceChksum",
    'COLLECTION_KW' => "collection",
    'IRODS_ADMIN_KW' => "irodsAdmin",
    'RESC_ZONE_KW' => "zoneName",
    'RESC_LOC_KW' => "rescLoc",
    'RESC_TYPE_KW' => "rescType",
    'RESC_CLASS_KW' => "rescClass",
    'RESC_VAULT_PATH_KW' => "rescVaultPath",
    'NUM_OPEN_PORTS_KW' => "numOpenPorts",
    'PARA_OPR_KW' => "paraOpr",
    'GATEWAY_ADDR_KW' => "gateWayAddr",
    'RESC_MAX_OBJ_SIZE_KW' => "rescMaxObjSize",
    'FREE_SPACE_KW' => "freeSpace",
    'FREE_SPACE_TIME_KW' => "freeSpaceTime",
    'FREE_SPACE_TIMESTAMP_KW' => "freeSpaceTimeStamp",
    'RESC_TYPE_INX_KW' => "rescTypeInx",
    'RESC_CLASS_INX_KW' => "rescClassInx",
    'RESC_ID_KW' => "rescId",
    'RESC_INFO_KW' => "rescInfo",
    'RESC_COMMENTS_KW' => "rescComments",
    'RESC_CREATE_KW' => "rescCreate",
    'RESC_MODIFY_KW' => "rescModify",
    'USER_NAME_CLIENT_KW' => "userNameClient",
    'RODS_ZONE_CLIENT_KW' => "rodsZoneClient",
    'HOST_CLIENT_KW' => "hostClient",
    'USER_TYPE_CLIENT_KW' => "userTypeClient",
    'AUTH_STR_CLIENT_KW' => "authStrClient",
    'USER_AUTH_SCHEME_CLIENT_KW' => "userAuthSchemeClient",
    'USER_INFO_CLIENT_KW' => "userInfoClient",
    'USER_COMMENT_CLIENT_KW' => "userCommentClient",
    'USER_CREATE_CLIENT_KW' => "userCreateClient",
    'USER_MODIFY_CLIENT_KW' => "userModifyClient",
    'USER_NAME_PROXY_KW' => "userNameProxy",
    'RODS_ZONE_PROXY_KW' => "rodsZoneProxy",
    'HOST_PROXY_KW' => "hostProxy",
    'USER_TYPE_PROXY_KW' => "userTypeProxy",
    'AUTH_STR_PROXY_KW' => "authStrProxy",
    'USER_AUTH_SCHEME_PROXY_KW' => "userAuthSchemeProxy",
    'USER_INFO_PROXY_KW' => "userInfoProxy",
    'USER_COMMENT_PROXY_KW' => "userCommentProxy",
    'USER_CREATE_PROXY_KW' => "userCreateProxy",
    'USER_MODIFY_PROXY_KW' => "userModifyProxy",
    'ACCESS_PERMISSION_KW' => "accessPermission",
    'COLL_NAME_KW' => "collName",
    'COLL_PARENT_NAME_KW' => "collParentName",
    'COLL_OWNER_NAME_KW' => "collOwnername",
    'COLL_OWNER_ZONE_KW' => "collOwnerZone",
    'COLL_MAP_ID_KW' => "collMapId",
    'COLL_INHERITANCE_KW' => "collInheritance",
    'COLL_COMMENTS_KW' => "collComments",
    'COLL_EXPIRY_KW' => "collExpiry",
    'COLL_CREATE_KW' => "collCreate",
    'COLL_MODIFY_KW' => "collModify",
    'COLL_ACCESS_KW' => "collAccess",
    'COLL_ACCESS_INX_KW' => "collAccessInx",
    'COLL_ID_KW' => "collId",
    'RULE_NAME_KW' => "ruleName",
    'RULE_REI_FILE_PATH_KW' => "reiFilePath",
    'RULE_USER_NAME_KW' => "userName",
    'RULE_EXE_ADDRESS_KW' => "exeAddress",
    'RULE_EXE_TIME_KW' => "exeTime",
    'RULE_EXE_FREQUENCY_KW' => "exeFrequency",
    'RULE_PRIORITY_KW' => "priority",
    'RULE_ESTIMATE_EXE_TIME_KW' => "estimateExeTime",
    'RULE_NOTIFICATION_ADDR_KW' => "notificationAddr",
    'RULE_LAST_EXE_TIME_KW' => "lastExeTime",
    'RULE_EXE_STATUS_KW' => "exeStatus",
);
$GLOBALS['PRODS_GENQUE_KEYWD_REV'] = array(
    "all" => 'ALL_KW',
    "copies" => 'COPIES_KW',
    "execLocally" => 'EXEC_LOCALLY_KW',
    "forceFlag" => 'FORCE_FLAG_KW',
    "cliInSvrFirewall" => 'CLI_IN_SVR_FIREWALL_KW',
    "regChksum" => 'REG_CHKSUM_KW',
    "verifyChksum" => 'VERIFY_CHKSUM_KW',
    "verifyBySize" => 'VERIFY_BY_SIZE_KW',
    "objPath" => 'OBJ_PATH_KW',
    "rescName" => 'RESC_NAME_KW',
    "destRescName" => 'DEST_RESC_NAME_KW',
    "backupRescName" => 'BACKUP_RESC_NAME_KW',
    "dataType" => 'DATA_TYPE_KW',
    "dataSize" => 'DATA_SIZE_KW',
    "chksum" => 'CHKSUM_KW',
    "version" => 'VERSION_KW',
    "filePath" => 'FILE_PATH_KW',
    "replNum" => 'REPL_NUM_KW',
    "replStatus" => 'REPL_STATUS_KW',
    "allReplStatus" => 'ALL_REPL_STATUS_KW',
    "dataIncluded" => 'DATA_INCLUDED_KW',
    "dataOwner" => 'DATA_OWNER_KW',
    "dataOwnerZone" => 'DATA_OWNER_ZONE_KW',
    "dataExpiry" => 'DATA_EXPIRY_KW',
    "dataComments" => 'DATA_COMMENTS_KW',
    "dataCreate" => 'DATA_CREATE_KW',
    "dataModify" => 'DATA_MODIFY_KW',
    "dataAccess" => 'DATA_ACCESS_KW',
    "dataAccessInx" => 'DATA_ACCESS_INX_KW',
    "noOpenFlag" => 'NO_OPEN_FLAG_KW',
    "streaming" => 'STREAMING_KW',
    "dataId" => 'DATA_ID_KW',
    "collId" => 'COLL_ID_KW',
    "rescGroupName" => 'RESC_GROUP_NAME_KW',
    "statusString" => 'STATUS_STRING_KW',
    "dataMapId" => 'DATA_MAP_ID_KW',
    "noParaOpr" => 'NO_PARA_OP_KW',
    "localPath" => 'LOCAL_PATH_KW',
    "rsyncMode" => 'RSYNC_MODE_KW',
    "rsyncDestPath" => 'RSYNC_DEST_PATH_KW',
    "rsyncChksum" => 'RSYNC_CHKSUM_KW',
    "ChksumAll" => 'CHKSUM_ALL_KW',
    "forceChksum" => 'FORCE_CHKSUM_KW',
    "collection" => 'COLLECTION_KW',
    "irodsAdmin" => 'IRODS_ADMIN_KW',
    "zoneName" => 'RESC_ZONE_KW',
    "rescLoc" => 'RESC_LOC_KW',
    "rescType" => 'RESC_TYPE_KW',
    "rescClass" => 'RESC_CLASS_KW',
    "rescVaultPath" => 'RESC_VAULT_PATH_KW',
    "numOpenPorts" => 'NUM_OPEN_PORTS_KW',
    "paraOpr" => 'PARA_OPR_KW',
    "gateWayAddr" => 'GATEWAY_ADDR_KW',
    "rescMaxObjSize" => 'RESC_MAX_OBJ_SIZE_KW',
    "freeSpace" => 'FREE_SPACE_KW',
    "freeSpaceTime" => 'FREE_SPACE_TIME_KW',
    "freeSpaceTimeStamp" => 'FREE_SPACE_TIMESTAMP_KW',
    "rescTypeInx" => 'RESC_TYPE_INX_KW',
    "rescClassInx" => 'RESC_CLASS_INX_KW',
    "rescId" => 'RESC_ID_KW',
    "rescInfo" => 'RESC_INFO_KW',
    "rescComments" => 'RESC_COMMENTS_KW',
    "rescCreate" => 'RESC_CREATE_KW',
    "rescModify" => 'RESC_MODIFY_KW',
    "userNameClient" => 'USER_NAME_CLIENT_KW',
    "rodsZoneClient" => 'RODS_ZONE_CLIENT_KW',
    "hostClient" => 'HOST_CLIENT_KW',
    "userTypeClient" => 'USER_TYPE_CLIENT_KW',
    "authStrClient" => 'AUTH_STR_CLIENT_KW',
    "userAuthSchemeClient" => 'USER_AUTH_SCHEME_CLIENT_KW',
    "userInfoClient" => 'USER_INFO_CLIENT_KW',
    "userCommentClient" => 'USER_COMMENT_CLIENT_KW',
    "userCreateClient" => 'USER_CREATE_CLIENT_KW',
    "userModifyClient" => 'USER_MODIFY_CLIENT_KW',
    "userNameProxy" => 'USER_NAME_PROXY_KW',
    "rodsZoneProxy" => 'RODS_ZONE_PROXY_KW',
    "hostProxy" => 'HOST_PROXY_KW',
    "userTypeProxy" => 'USER_TYPE_PROXY_KW',
    "authStrProxy" => 'AUTH_STR_PROXY_KW',
    "userAuthSchemeProxy" => 'USER_AUTH_SCHEME_PROXY_KW',
    "userInfoProxy" => 'USER_INFO_PROXY_KW',
    "userCommentProxy" => 'USER_COMMENT_PROXY_KW',
    "userCreateProxy" => 'USER_CREATE_PROXY_KW',
    "userModifyProxy" => 'USER_MODIFY_PROXY_KW',
    "accessPermission" => 'ACCESS_PERMISSION_KW',
    "collName" => 'COLL_NAME_KW',
    "collParentName" => 'COLL_PARENT_NAME_KW',
    "collOwnername" => 'COLL_OWNER_NAME_KW',
    "collOwnerZone" => 'COLL_OWNER_ZONE_KW',
    "collMapId" => 'COLL_MAP_ID_KW',
    "collInheritance" => 'COLL_INHERITANCE_KW',
    "collComments" => 'COLL_COMMENTS_KW',
    "collExpiry" => 'COLL_EXPIRY_KW',
    "collCreate" => 'COLL_CREATE_KW',
    "collModify" => 'COLL_MODIFY_KW',
    "collAccess" => 'COLL_ACCESS_KW',
    "collAccessInx" => 'COLL_ACCESS_INX_KW',
    "collId" => 'COLL_ID_KW',
    "ruleName" => 'RULE_NAME_KW',
    "reiFilePath" => 'RULE_REI_FILE_PATH_KW',
    "userName" => 'RULE_USER_NAME_KW',
    "exeAddress" => 'RULE_EXE_ADDRESS_KW',
    "exeTime" => 'RULE_EXE_TIME_KW',
    "exeFrequency" => 'RULE_EXE_FREQUENCY_KW',
    "priority" => 'RULE_PRIORITY_KW',
    "estimateExeTime" => 'RULE_ESTIMATE_EXE_TIME_KW',
    "notificationAddr" => 'RULE_NOTIFICATION_ADDR_KW',
    "lastExeTime" => 'RULE_LAST_EXE_TIME_KW',
    "exeStatus" => 'RULE_EXE_STATUS_KW',
);
?>
