<?php
/* This file is generated by setRodsGenQueryNum.php   Please modify that file if you wish to update the    Gen Query number.            */
$GLOBALS['PRODS_GENQUE_NUMS'] = array(
    'MAX_SQL_ATTR' => '50',
    'MAX_SQL_ROWS' => '500',
    'ORDER_BY' => '1024',
    'ORDER_BY_DESC' => '2048',
    'RETURN_TOTAL_ROW_COUNT' => '32',
    'SELECT_MIN' => '2',
    'SELECT_MAX' => '3',
    'SELECT_SUM' => '4',
    'SELECT_AVG' => '5',
    'SELECT_COUNT' => '6',
    'COL_ZONE_ID' => '101',
    'COL_ZONE_NAME' => '102',
    'COL_USER_ID' => '201',
    'COL_USER_NAME' => '202',
    'COL_USER_TYPE' => '203',
    'COL_USER_ZONE' => '204',
    'COL_USER_DN' => '205',
    'COL_USER_INFO' => '206',
    'COL_USER_COMMENT' => '207',
    'COL_USER_CREATE_TIME' => '208',
    'COL_USER_MODIFY_TIME' => '209',
    'COL_R_RESC_ID' => '301',
    'COL_R_RESC_NAME' => '302',
    'COL_R_ZONE_NAME' => '303',
    'COL_R_TYPE_NAME' => '304',
    'COL_R_CLASS_NAME' => '305',
    'COL_R_LOC' => '306',
    'COL_R_VAULT_PATH' => '307',
    'COL_R_FREE_SPACE' => '308',
    'COL_R_RESC_INFO' => '309',
    'COL_R_RESC_COMMENT' => '310',
    'COL_R_CREATE_TIME' => '311',
    'COL_R_MODIFY_TIME' => '312',
    'COL_D_DATA_ID' => '401',
    'COL_D_COLL_ID' => '402',
    'COL_DATA_NAME' => '403',
    'COL_DATA_REPL_NUM' => '404',
    'COL_DATA_VERSION' => '405',
    'COL_DATA_TYPE_NAME' => '406',
    'COL_DATA_SIZE' => '407',
    'COL_D_RESC_GROUP_NAME' => '408',
    'COL_D_RESC_NAME' => '409',
    'COL_D_DATA_PATH' => '410',
    'COL_D_OWNER_NAME' => '411',
    'COL_D_OWNER_ZONE' => '412',
    'COL_D_REPL_STATUS' => '413',
    'COL_D_DATA_STATUS' => '414',
    'COL_D_DATA_CHECKSUM' => '415',
    'COL_D_EXPIRY' => '416',
    'COL_D_MAP_ID' => '417',
    'COL_D_COMMENTS' => '418',
    'COL_D_CREATE_TIME' => '419',
    'COL_D_MODIFY_TIME' => '420',
    'COL_COLL_ID' => '500',
    'COL_COLL_NAME' => '501',
    'COL_COLL_PARENT_NAME' => '502',
    'COL_COLL_OWNER_NAME' => '503',
    'COL_COLL_OWNER_ZONE' => '504',
    'COL_COLL_MAP_ID' => '505',
    'COL_COLL_INHERITANCE' => '506',
    'COL_COLL_COMMENTS' => '507',
    'COL_COLL_CREATE_TIME' => '508',
    'COL_COLL_MODIFY_TIME' => '509',
    'COL_COLL_TYPE' => '510',
    'COL_COLL_INFO1' => '511',
    'COL_COLL_INFO2' => '512',
    'COL_META_DATA_ATTR_NAME' => '600',
    'COL_META_DATA_ATTR_VALUE' => '601',
    'COL_META_DATA_ATTR_UNITS' => '602',
    'COL_META_DATA_ATTR_ID' => '603',
    'COL_META_COLL_ATTR_NAME' => '610',
    'COL_META_COLL_ATTR_VALUE' => '611',
    'COL_META_COLL_ATTR_UNITS' => '612',
    'COL_META_COLL_ATTR_ID' => '613',
    'COL_META_NAMESPACE_COLL' => '620',
    'COL_META_NAMESPACE_DATA' => '621',
    'COL_META_NAMESPACE_RESC' => '622',
    'COL_META_NAMESPACE_USER' => '623',
    'COL_META_RESC_ATTR_NAME' => '630',
    'COL_META_RESC_ATTR_VALUE' => '631',
    'COL_META_RESC_ATTR_UNITS' => '632',
    'COL_META_RESC_ATTR_ID' => '633',
    'COL_META_USER_ATTR_NAME' => '640',
    'COL_META_USER_ATTR_VALUE' => '641',
    'COL_META_USER_ATTR_UNITS' => '642',
    'COL_META_USER_ATTR_ID' => '643',
    'COL_DATA_ACCESS_TYPE' => '700',
    'COL_DATA_ACCESS_NAME' => '701',
    'COL_DATA_TOKEN_NAMESPACE' => '702',
    'COL_DATA_ACCESS_USER_ID' => '703',
    'COL_DATA_ACCESS_DATA_ID' => '704',
    'COL_RESC_GROUP_RESC_ID' => '800',
    'COL_RESC_GROUP_NAME' => '801',
    'COL_USER_GROUP_ID' => '900',
    'COL_USER_GROUP_NAME' => '901',
    'COL_RULE_EXEC_ID' => '1000',
    'COL_RULE_EXEC_NAME' => '1001',
    'COL_RULE_EXEC_REI_FILE_PATH' => '1002',
    'COL_RULE_EXEC_USER_NAME' => '1003',
    'COL_RULE_EXEC_ADDRESS' => '1004',
    'COL_RULE_EXEC_TIME' => '1005',
    'COL_RULE_EXEC_FREQUENCY' => '1006',
    'COL_RULE_EXEC_PRIORITY' => '1007',
    'COL_RULE_EXEC_ESTIMATED_EXE_TIME' => '1008',
    'COL_RULE_EXEC_NOTIFICATION_ADDR' => '1009',
    'COL_RULE_EXEC_LAST_EXE_TIME' => '1010',
    'COL_RULE_EXEC_STATUS' => '1011',
    'COL_TOKEN_NAMESPACE' => '1100',
    'COL_TOKEN_ID' => '1101',
    'COL_TOKEN_NAME' => '1102',
    'COL_TOKEN_VALUE' => '1103',
    'COL_TOKEN_VALUE2' => '1104',
    'COL_TOKEN_VALUE3' => '1105',
    'COL_TOKEN_COMMENT' => '1106',
);
$GLOBALS['PRODS_GENQUE_NUMS_REV'] = array(
    '50' => 'MAX_SQL_ATTR',
    '500' => 'MAX_SQL_ROWS',
    '1024' => 'ORDER_BY',
    '2048' => 'ORDER_BY_DESC',
    '32' => 'RETURN_TOTAL_ROW_COUNT',
    '2' => 'SELECT_MIN',
    '3' => 'SELECT_MAX',
    '4' => 'SELECT_SUM',
    '5' => 'SELECT_AVG',
    '6' => 'SELECT_COUNT',
    '101' => 'COL_ZONE_ID',
    '102' => 'COL_ZONE_NAME',
    '201' => 'COL_USER_ID',
    '202' => 'COL_USER_NAME',
    '203' => 'COL_USER_TYPE',
    '204' => 'COL_USER_ZONE',
    '205' => 'COL_USER_DN',
    '206' => 'COL_USER_INFO',
    '207' => 'COL_USER_COMMENT',
    '208' => 'COL_USER_CREATE_TIME',
    '209' => 'COL_USER_MODIFY_TIME',
    '301' => 'COL_R_RESC_ID',
    '302' => 'COL_R_RESC_NAME',
    '303' => 'COL_R_ZONE_NAME',
    '304' => 'COL_R_TYPE_NAME',
    '305' => 'COL_R_CLASS_NAME',
    '306' => 'COL_R_LOC',
    '307' => 'COL_R_VAULT_PATH',
    '308' => 'COL_R_FREE_SPACE',
    '309' => 'COL_R_RESC_INFO',
    '310' => 'COL_R_RESC_COMMENT',
    '311' => 'COL_R_CREATE_TIME',
    '312' => 'COL_R_MODIFY_TIME',
    '401' => 'COL_D_DATA_ID',
    '402' => 'COL_D_COLL_ID',
    '403' => 'COL_DATA_NAME',
    '404' => 'COL_DATA_REPL_NUM',
    '405' => 'COL_DATA_VERSION',
    '406' => 'COL_DATA_TYPE_NAME',
    '407' => 'COL_DATA_SIZE',
    '408' => 'COL_D_RESC_GROUP_NAME',
    '409' => 'COL_D_RESC_NAME',
    '410' => 'COL_D_DATA_PATH',
    '411' => 'COL_D_OWNER_NAME',
    '412' => 'COL_D_OWNER_ZONE',
    '413' => 'COL_D_REPL_STATUS',
    '414' => 'COL_D_DATA_STATUS',
    '415' => 'COL_D_DATA_CHECKSUM',
    '416' => 'COL_D_EXPIRY',
    '417' => 'COL_D_MAP_ID',
    '418' => 'COL_D_COMMENTS',
    '419' => 'COL_D_CREATE_TIME',
    '420' => 'COL_D_MODIFY_TIME',
    '500' => 'COL_COLL_ID',
    '501' => 'COL_COLL_NAME',
    '502' => 'COL_COLL_PARENT_NAME',
    '503' => 'COL_COLL_OWNER_NAME',
    '504' => 'COL_COLL_OWNER_ZONE',
    '505' => 'COL_COLL_MAP_ID',
    '506' => 'COL_COLL_INHERITANCE',
    '507' => 'COL_COLL_COMMENTS',
    '508' => 'COL_COLL_CREATE_TIME',
    '509' => 'COL_COLL_MODIFY_TIME',
    '510' => 'COL_COLL_TYPE',
    '511' => 'COL_COLL_INFO1',
    '512' => 'COL_COLL_INFO2',
    '600' => 'COL_META_DATA_ATTR_NAME',
    '601' => 'COL_META_DATA_ATTR_VALUE',
    '602' => 'COL_META_DATA_ATTR_UNITS',
    '603' => 'COL_META_DATA_ATTR_ID',
    '610' => 'COL_META_COLL_ATTR_NAME',
    '611' => 'COL_META_COLL_ATTR_VALUE',
    '612' => 'COL_META_COLL_ATTR_UNITS',
    '613' => 'COL_META_COLL_ATTR_ID',
    '620' => 'COL_META_NAMESPACE_COLL',
    '621' => 'COL_META_NAMESPACE_DATA',
    '622' => 'COL_META_NAMESPACE_RESC',
    '623' => 'COL_META_NAMESPACE_USER',
    '630' => 'COL_META_RESC_ATTR_NAME',
    '631' => 'COL_META_RESC_ATTR_VALUE',
    '632' => 'COL_META_RESC_ATTR_UNITS',
    '633' => 'COL_META_RESC_ATTR_ID',
    '640' => 'COL_META_USER_ATTR_NAME',
    '641' => 'COL_META_USER_ATTR_VALUE',
    '642' => 'COL_META_USER_ATTR_UNITS',
    '643' => 'COL_META_USER_ATTR_ID',
    '700' => 'COL_DATA_ACCESS_TYPE',
    '701' => 'COL_DATA_ACCESS_NAME',
    '702' => 'COL_DATA_TOKEN_NAMESPACE',
    '703' => 'COL_DATA_ACCESS_USER_ID',
    '704' => 'COL_DATA_ACCESS_DATA_ID',
    '800' => 'COL_RESC_GROUP_RESC_ID',
    '801' => 'COL_RESC_GROUP_NAME',
    '900' => 'COL_USER_GROUP_ID',
    '901' => 'COL_USER_GROUP_NAME',
    '1000' => 'COL_RULE_EXEC_ID',
    '1001' => 'COL_RULE_EXEC_NAME',
    '1002' => 'COL_RULE_EXEC_REI_FILE_PATH',
    '1003' => 'COL_RULE_EXEC_USER_NAME',
    '1004' => 'COL_RULE_EXEC_ADDRESS',
    '1005' => 'COL_RULE_EXEC_TIME',
    '1006' => 'COL_RULE_EXEC_FREQUENCY',
    '1007' => 'COL_RULE_EXEC_PRIORITY',
    '1008' => 'COL_RULE_EXEC_ESTIMATED_EXE_TIME',
    '1009' => 'COL_RULE_EXEC_NOTIFICATION_ADDR',
    '1010' => 'COL_RULE_EXEC_LAST_EXE_TIME',
    '1011' => 'COL_RULE_EXEC_STATUS',
    '1100' => 'COL_TOKEN_NAMESPACE',
    '1101' => 'COL_TOKEN_ID',
    '1102' => 'COL_TOKEN_NAME',
    '1103' => 'COL_TOKEN_VALUE',
    '1104' => 'COL_TOKEN_VALUE2',
    '1105' => 'COL_TOKEN_VALUE3',
    '1106' => 'COL_TOKEN_COMMENT',
);
?>
