<?php

require_once dirname(__FILE__) . '/../../../prods/src/RODSQueryCondition.class.php';

/**
 * Test class for RODSQueryCondition.
 * Generated by PHPUnit on 2011-02-24 at 16:39:17.
 */
class RODSQueryConditionTest extends PHPUnit_Framework_TestCase {

    /**
     * @var RODSQueryCondition
     */
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp() {
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown() {

    }

    /**
     * @todo Implement test__toString().
     */
    public function test__toString() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

}

?>
