<?php

require_once dirname(__FILE__) . '/../../../prods/src/RODSKeyValPair.class.php';

/**
 * Test class for RODSKeyValPair.
 * Generated by PHPUnit on 2011-02-24 at 16:39:12.
 */
class RODSKeyValPairTest extends PHPUnit_Framework_TestCase {

    /**
     * @var RODSKeyValPair
     */
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp() {
        $this->object = new RODSKeyValPair;
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown() {

    }

    /**
     * @todo Implement testAddPair().
     */
    public function testAddPair() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

    /**
     * @todo Implement testMakePacket().
     */
    public function testMakePacket() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

    /**
     * @todo Implement testFromPacket().
     */
    public function testFromPacket() {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
                'This test has not been implemented yet.'
        );
    }

}

?>
